@@ -323,7 +323,7 @@ reg_name_search (const struct reg_name *regs,
    the name and the function returns TRUE.  Otherwise the input pointer
    is left alone and the function returns FALSE.  */
 
-static bfd_boolean
+static bool
 get_register_name (expressionS *           expressionP,
 		   const struct reg_name * table,
 		   size_t                  table_length)
@@ -352,52 +352,52 @@ get_register_name (expressionS *           expressionP,
       expressionP->X_add_symbol = NULL;
       expressionP->X_op_symbol = NULL;
 
-      return TRUE;
+      return true;
     }
 
   /* Reset the line as if we had not done anything.  */
   input_line_pointer = start;
-  return FALSE;
+  return false;
 }
 
-static bfd_boolean
+static bool
 r_register_name (expressionS *expressionP)
 {
   return get_register_name (expressionP, r_registers, ARRAY_SIZE (r_registers));
 }
 
 
-static bfd_boolean
+static bool
 xr_register_name (expressionS *expressionP)
 {
   return get_register_name (expressionP, xr_registers, ARRAY_SIZE (xr_registers));
 }
 
-static bfd_boolean
+static bool
 data_register_name (expressionS *expressionP)
 {
   return get_register_name (expressionP, data_registers, ARRAY_SIZE (data_registers));
 }
 
-static bfd_boolean
+static bool
 address_register_name (expressionS *expressionP)
 {
   return get_register_name (expressionP, address_registers, ARRAY_SIZE (address_registers));
 }
 
-static bfd_boolean
+static bool
 float_register_name (expressionS *expressionP)
 {
   return get_register_name (expressionP, float_registers, ARRAY_SIZE (float_registers));
 }
 
-static bfd_boolean
+static bool
 double_register_name (expressionS *expressionP)
 {
   return get_register_name (expressionP, double_registers, ARRAY_SIZE (double_registers));
 }
 
-static bfd_boolean
+static bool
 other_register_name (expressionS *expressionP)
 {
   int reg_number;
@@ -425,12 +425,12 @@ other_register_name (expressionS *expressionP)
       expressionP->X_add_symbol = NULL;
       expressionP->X_op_symbol = NULL;
 
-      return TRUE;
+      return true;
     }
 
   /* Reset the line as if we had not done anything.  */
   input_line_pointer = start;
-  return FALSE;
+  return false;
 }
 
 void
@@ -455,7 +455,7 @@ md_undefined_symbol (char *name ATTRIBUTE_UNUSED)
 const char *
 md_atof (int type, char *litp, int *sizep)
 {
-  return ieee_md_atof (type, litp, sizep, FALSE);
+  return ieee_md_atof (type, litp, sizep, false);
 }
 
 void
@@ -1073,7 +1073,7 @@ mn10300_cons_fix_new (fragS *frag, int off, int size, expressionS *exp,
   fix_new_exp (frag, off, size, &fixup.exp, 0, fixup.reloc);
 }
 
-static bfd_boolean
+static bool
 check_operand (const struct mn10300_operand *operand,
 	       offsetT val)
 {
@@ -1104,9 +1104,9 @@ check_operand (const struct mn10300_operand *operand,
       test = val;
 
       if (test < (offsetT) min || test > (offsetT) max)
-	return FALSE;
+	return false;
     }
-  return TRUE;
+  return true;
 }
 
 /* Insert an operand value into an instruction.  */
@@ -2155,7 +2155,7 @@ md_assemble (char *str)
     }
 
   /* Label this frag as one that contains instructions.  */
-  frag_now->tc_frag_data = TRUE;
+  frag_now->tc_frag_data = true;
 }
 
 /* If while processing a fixup, a reloc really needs to be created
@@ -2278,7 +2278,7 @@ tc_gen_reloc (asection *seg ATTRIBUTE_UNUSED, fixS *fixp)
 /* Returns true iff the symbol attached to the frag is at a known location
    in the given section, (and hence the relocation to it can be relaxed by
    the assembler).  */
-static inline bfd_boolean
+static inline bool
 has_known_symbol_location (fragS * fragp, asection * sec)
 {
   symbolS * sym = fragp->fr_symbol;
@@ -2400,37 +2400,37 @@ md_apply_fix (fixS * fixP, valueT * valP, segT seg)
 /* Return zero if the fixup in fixp should be left alone and not
    adjusted.  */
 
-bfd_boolean
+bool
 mn10300_fix_adjustable (struct fix *fixp)
 {
   if (fixp->fx_pcrel)
     {
       if (TC_FORCE_RELOCATION_LOCAL (fixp))
-	return FALSE;
+	return false;
     }
   /* Non-relative relocs can (and must) be adjusted if they do
      not meet the criteria below, or the generic criteria.  */
   else if (TC_FORCE_RELOCATION (fixp))
-    return FALSE;
+    return false;
 
   /* Do not adjust relocations involving symbols in code sections,
      because it breaks linker relaxations.  This could be fixed in the
      linker, but this fix is simpler, and it pretty much only affects
      object size a little bit.  */
   if (S_GET_SEGMENT (fixp->fx_addsy)->flags & SEC_CODE)
-    return FALSE;
+    return false;
 
   /* Likewise, do not adjust symbols that won't be merged, or debug
      symbols, because they too break relaxation.  We do want to adjust
      other mergeable symbols, like .rodata, because code relaxations
      need section-relative symbols to properly relax them.  */
   if (! (S_GET_SEGMENT (fixp->fx_addsy)->flags & SEC_MERGE))
-    return FALSE;
+    return false;
 
-  if (strncmp (S_GET_SEGMENT (fixp->fx_addsy)->name, ".debug", 6) == 0)
-    return FALSE;
+  if (startswith (S_GET_SEGMENT (fixp->fx_addsy)->name, ".debug"))
+    return false;
 
-  return TRUE;
+  return true;
 }
 
 static void
@@ -2447,7 +2447,7 @@ mn10300_end_of_match (char *cont, const char *what)
 {
   int len = strlen (what);
 
-  if (strncmp (cont, what, strlen (what)) == 0
+  if (startswith (cont, what)
       && ! is_part_of_name (cont[len]))
     return cont + len;
 
@@ -2549,10 +2549,10 @@ const pseudo_typeS md_pseudo_table[] =
    subtraction of two same-section symbols cannot be computed by
    the assembler.  */
 
-bfd_boolean
+bool
 mn10300_allow_local_subtract (expressionS * left, expressionS * right, segT section)
 {
-  bfd_boolean result;
+  bool result;
   fragS * left_frag;
   fragS * right_frag;
   fragS * frag;
@@ -2560,11 +2560,11 @@ mn10300_allow_local_subtract (expressionS * left, expressionS * right, segT sect
   /* If we are not performing linker relaxation then we have nothing
      to worry about.  */
   if (linkrelax == 0)
-    return TRUE;
+    return true;
 
   /* If the symbols are not in a code section then they are OK.  */
   if ((section->flags & SEC_CODE) == 0)
-    return TRUE;
+    return true;
 
   /* Otherwise we have to scan the fragments between the two symbols.
      If any instructions are found then we have to assume that linker
@@ -2576,11 +2576,11 @@ mn10300_allow_local_subtract (expressionS * left, expressionS * right, segT sect
   if (left_frag == right_frag)
     return ! left_frag->tc_frag_data;
 
-  result = TRUE;
+  result = true;
   for (frag = left_frag; frag != NULL; frag = frag->fr_next)
     {
       if (frag->tc_frag_data)
-	result = FALSE;
+	result = false;
       if (frag == right_frag)
 	break;
     }
@@ -2589,7 +2589,7 @@ mn10300_allow_local_subtract (expressionS * left, expressionS * right, segT sect
     for (frag = right_frag; frag != NULL; frag = frag->fr_next)
       {
 	if (frag->tc_frag_data)
-	  result = FALSE;
+	  result = false;
 	if (frag == left_frag)
 	  break;
       }
@@ -2597,7 +2597,7 @@ mn10300_allow_local_subtract (expressionS * left, expressionS * right, segT sect
   if (frag == NULL)
     /* The two symbols are on disjoint fragment chains
        - we cannot possibly compute their difference.  */
-    return FALSE;
+    return false;
 
   return result;
 }
@@ -2622,17 +2622,17 @@ mn10300_handle_align (fragS *frag)
        The offset from the symbol is used to record the power-of-two alignment
        value.  The size is set to 0 because the frag may already be aligned,
        thus causing cvt_frag_to_fill to reduce the size of the frag to zero.  */
-    fix_new (frag, frag->fr_fix, 0, & abs_symbol, frag->fr_offset, FALSE,
+    fix_new (frag, frag->fr_fix, 0, & abs_symbol, frag->fr_offset, false,
 	     BFD_RELOC_MN10300_ALIGN);
 }
 
-bfd_boolean
+bool
 mn10300_force_relocation (struct fix * fixp)
 {
   if (linkrelax
       && (fixp->fx_pcrel
 	  || fixp->fx_r_type == BFD_RELOC_MN10300_ALIGN))
-    return TRUE;
+    return true;
 
   return generic_force_reloc (fixp);
 }
