@@ -21,7 +21,7 @@
    02110-1301, USA.  */
 
 #include "as.h"
-#include "bfd_stdint.h"
+#include <stdint.h>
 #include "opcode/pru.h"
 #include "elf/pru.h"
 #include "tc-pru.h"
@@ -66,14 +66,14 @@ struct pru_opt_s
 {
   /* -mno-link-relax / -mlink-relax: generate (or not)
      relocations for linker relaxation.  */
-  bfd_boolean link_relax;
+  bool link_relax;
 
   /* -mno-warn-regname-label: do not output a warning that a label name
      matches a register name.  */
-  bfd_boolean warn_regname_label;
+  bool warn_regname_label;
 };
 
-static struct pru_opt_s pru_opt = { TRUE, TRUE };
+static struct pru_opt_s pru_opt = { true, true };
 
 const char *md_shortopts = "r";
 
@@ -188,7 +188,7 @@ md_number_to_chars (char *buf, valueT val, int n)
 const char *
 md_atof (int type, char *litP, int *sizeP)
 {
-  return ieee_md_atof (type, litP, sizeP, FALSE);
+  return ieee_md_atof (type, litP, sizeP, false);
 }
 
 /* Return true if STR starts with PREFIX, which should be a string literal.  */
@@ -246,7 +246,7 @@ pru_align (int log_size, const char *pfill, symbolS *label)
       if (label != NULL && !switched_seg_p)
 	{
 	  symbolS *sym;
-	  int label_seen = FALSE;
+	  int label_seen = false;
 	  struct frag *old_frag;
 	  valueT old_value;
 	  valueT new_value;
@@ -272,7 +272,7 @@ pru_align (int log_size, const char *pfill, symbolS *label)
 	    if (symbol_get_frag (sym) == old_frag
 		&& S_GET_VALUE (sym) == old_value)
 	      {
-		label_seen = TRUE;
+		label_seen = true;
 		symbol_set_frag (sym, frag_now);
 		S_SET_VALUE (sym, new_value);
 	      }
@@ -425,13 +425,13 @@ s_pru_set (int equiv)
   SKIP_WHITESPACE ();
   if (is_end_of_line[(unsigned char) *input_line_pointer])
     {
-      bfd_boolean done = TRUE;
+      bool done = true;
       *endline = 0;
 
       if (!strcmp (directive, "no_warn_regname_label"))
-	  pru_opt.warn_regname_label = FALSE;
+	  pru_opt.warn_regname_label = false;
       else
-	done = FALSE;
+	done = false;
 
       if (done)
 	{
@@ -491,7 +491,7 @@ md_convert_frag (bfd *headers ATTRIBUTE_UNUSED, segT segment ATTRIBUTE_UNUSED,
 }
 
 
-static bfd_boolean
+static bool
 relaxable_section (asection *sec)
 {
   return ((sec->flags & SEC_DEBUGGING) == 0
@@ -1404,7 +1404,7 @@ pru_parse_args (pru_insn_infoS *insn ATTRIBUTE_UNUSED, char *argstr,
   int i;
   p = argstr;
   i = 0;
-  bfd_boolean terminate = FALSE;
+  bool terminate = false;
 
   /* This rest of this function is it too fragile and it mostly works,
      therefore special case this one.  */
@@ -1439,7 +1439,7 @@ pru_parse_args (pru_insn_infoS *insn ATTRIBUTE_UNUSED, char *argstr,
 	}
 
       if (*parsestr == '\0' || (p != NULL && *p == '\0'))
-	terminate = TRUE;
+	terminate = true;
       ++i;
     }
 
@@ -1516,13 +1516,13 @@ md_parse_option (int c, const char *arg ATTRIBUTE_UNUSED)
       pru_mode = PRU_MODE_TEST;
       break;
     case OPTION_LINK_RELAX:
-      pru_opt.link_relax = TRUE;
+      pru_opt.link_relax = true;
       break;
     case OPTION_NO_LINK_RELAX:
-      pru_opt.link_relax = FALSE;
+      pru_opt.link_relax = false;
       break;
     case OPTION_NO_WARN_REGNAME_LABEL:
-      pru_opt.warn_regname_label = FALSE;
+      pru_opt.warn_regname_label = false;
       break;
     default:
       return 0;
@@ -1835,7 +1835,7 @@ skip_space (char *s)
 int
 pru_parse_cons_expression (expressionS *exp, int nbytes)
 {
-  int is_pmem = FALSE;
+  int is_pmem = false;
   char *tmp;
 
   tmp = input_line_pointer = skip_space (input_line_pointer);
@@ -1852,7 +1852,7 @@ pru_parse_cons_expression (expressionS *exp, int nbytes)
 	  if (*input_line_pointer == '(')
 	    {
 	      input_line_pointer = skip_space (input_line_pointer + 1);
-	      is_pmem = TRUE;
+	      is_pmem = true;
 	      expression (exp);
 
 	      if (*input_line_pointer == ')')
@@ -1860,7 +1860,7 @@ pru_parse_cons_expression (expressionS *exp, int nbytes)
 	      else
 		{
 		  as_bad (_("`)' required"));
-		  is_pmem = FALSE;
+		  is_pmem = false;
 		}
 
 	      return is_pmem;
@@ -1933,24 +1933,24 @@ pru_frame_initial_instructions (void)
   cfi_add_CFA_def_cfa (fp_regno, 0);
 }
 
-bfd_boolean
+bool
 pru_allow_local_subtract (expressionS * left,
 			     expressionS * right,
 			     segT section)
 {
   /* If we are not in relaxation mode, subtraction is OK.  */
   if (!linkrelax)
-    return TRUE;
+    return true;
 
   /* If the symbols are not in a code section then they are OK.  */
   if ((section->flags & SEC_CODE) == 0)
-    return TRUE;
+    return true;
 
   if (left->X_add_symbol == right->X_add_symbol)
-    return TRUE;
+    return true;
 
   /* We have to assume that there may be instructions between the
      two symbols and that relaxation may increase the distance between
      them.  */
-  return FALSE;
+  return false;
 }
