@@ -1,5 +1,3 @@
-# If you change this file, please also look at files which source this one:
-# cskyelf_linux.sh
 SCRIPT_NAME=elf
 OUTPUT_FORMAT="elf32-csky-little"
 BIG_OUTPUT_FORMAT="elf32-csky-big"
@@ -7,9 +5,29 @@ LITTLE_OUTPUT_FORMAT="elf32-csky-little"
 NO_REL_RELOCS=yes
 TARGET_PAGE_SIZE=0x400
 MAXPAGESIZE="CONSTANT (MAXPAGESIZE)"
-TEXT_START_ADDR=0x8000
+TEXT_START_ADDR=0x60000000
+DATA_ADDR=0x20000000
+
+# The default address spaces
+# RAM:        0x0 - 0x1FFFFFFF
+# RAM: 0x20000000 - 0x3FFFFFFF
+# RAM: 0x60000000 - 0x7FFFFFFF
+#
+# There are some symbols used in the crt.S
+# __stack: The stack top
+# __heap_start: The heap start
+# __heap_end: The heap end
+# __csky_exit: Be used by qemu to check exit
+
+OTHER_SYMBOLS='
+  PROVIDE (__stack =  0x01000000 - 0x8);
+  PROVIDE (__heap_start = 0x00000100);
+  PROVIDE (__heap_end = 0x00900000);
+  PROVIDE (__csky_exit = 0x10002000);
+'
 CHECK_RELOCS_AFTER_OPEN_INPUT=yes
 NONPAGED_TEXT_START_ADDR=0
+ATTRS_SECTIONS='.csky.attributes 0 : { KEEP (*(.csky.attributes)) KEEP (*(.csky.attributes)) }'
 ARCH=csky
 EMBEDDED=yes
 EXTRA_EM_FILE=cskyelf
@@ -26,8 +44,8 @@ EXTRA_EM_FILE=cskyelf
 NOP=0
 
 ENTRY=__start
-OTHER_BSS_SYMBOLS="__bss_start__ = . ;"
-OTHER_BSS_END_SYMBOLS="__bss_end__ = . ;"
+OTHER_BSS_SYMBOLS="__sbss__ = . ;"
+OTHER_BSS_END_SYMBOLS="__ebss__ = . ;"
 
 # This sets the stack to the top of the simulator memory (2^19 bytes).
 # STACK_ADDR=0x80000
